"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sqlGetAllRows = exports.sqlGetAllColumns = exports.sqlExecute = void 0;
const oracledb_1 = __importDefault(require("oracledb"));
const process_1 = require("process");
const dotenv_1 = __importDefault(require("dotenv"));
dotenv_1.default.config();
/**
 * @description This method is use to execute sql query
 * @param query SQL query string to execute
 */
const sqlExecute = async (query) => {
    const local = `${process_1.env.RUN || "LOCAL"}`;
    console.log("Setting environment variables...");
    const oracleClient = local === "LOCAL" ? "../instantclient_21_8" : `${process_1.env.WORKSPACE}/opt/oracle/instantclient_21_8`;
    if (!process_1.env.NODE_ORACLE_SDK) {
        process_1.env.NODE_ORACLE_SDK = "instantclient";
        console.log("Initializing Oracle Instant Client...");
        oracledb_1.default.initOracleClient({ libDir: oracleClient });
    }
    const db_user = process_1.env.DB_USER;
    const db_password = process_1.env.DB_PASSWORD;
    console.log("ATP DB Username:", db_user);
    console.log("ATP DB Password:", db_password);
    // Set connection string
    let connection, connectString;
    switch (String(process_1.env.NODE_ENV).toUpperCase()) {
        case "DEV":
            connectString = `dev_low`;
            break;
        case "QA":
            connectString = `qa_low`;
            break;
        case "QAPINTLAB":
            connectString = `qapintlab1_low`;
            break;
        case "QACHAOS":
            connectString = `qachaos_low`;
            break;
        default:
            connectString = `qa_low`;
    }
    console.log(`Connection string is set using: ${connectString}`);
    try {
        let binds, options;
        // Get Connection
        connection = await oracledb_1.default.getConnection({
            user: db_user,
            password: db_password,
            connectString: connectString,
        });
        console.log("Successfully connected to Oracle ATP Database");
        console.log(`Executing SQL Query: ${query}`);
        // Set Binds
        binds = {};
        // Set options
        options = {
            outFormat: oracledb_1.default.OUT_FORMAT_OBJECT,
            resultSet: false,
        };
        // Execute Query
        const result = await connection.execute(query, binds, options);
        console.log(`QUERY [${query}] RESULT: \n`, result);
        return result;
    }
    catch (err) {
        console.log(`${err.message}`);
        return err.message;
    }
    finally {
        if (connection) {
            try {
                await connection.close();
            }
            catch (err) {
                console.log(`${err.message}`);
            }
        }
    }
};
exports.sqlExecute = sqlExecute;
/**
 * @description This method gets all columns from a specified Database SQL Query
 *
 * @param response SQL query string to execute
 */
const sqlGetAllColumns = async (response) => {
    try {
        return response.metaData;
    }
    catch (error) {
        console.log("FAILED", error);
    }
};
exports.sqlGetAllColumns = sqlGetAllColumns;
/**
 * @description This method gets all rows from a specified Database SQL Query
 *
 * @param response SQL query string to execute
 */
const sqlGetAllRows = async (response) => {
    try {
        return response.rows;
    }
    catch (error) {
        console.log("FAILED", error);
    }
};
exports.sqlGetAllRows = sqlGetAllRows;
//# sourceMappingURL=atp-db-connect.js.map